@@ -1,6 +1,10 @@
 DESCRIPTION="Python bindings for the QT6 cross-platform application and UI framework"
 
-EXT_VERSION=$(basename $PKG_PYSIDE6 .zip | cut -d "-" -f 5) 
+EXT_VERSION=$(basename $PKG_PYSIDE6 .zip | cut -d "-" -f 2) 
+
+LIBCLANG_PATH=/usr/lib
+
+[[ $(cmake --version | sed 2,5d | cut -d " " -f 3 | cut -d "." -f 1) == 4 ]] && OPTIONS="-D CMAKE_POLICY_VERSION_MINIMUM=3.5" || OPTIONS=""
 
 unzip ../$(basename $PKG_PYSIDE6)
 cd $(basename $PKG_PYSIDE6 .zip)
@@ -10,7 +14,7 @@ cd $(basename $PKG_PYSIDE6 .zip)
 mkdir build
 cd build
 
-cmake -D BUILD_TESTING=OFF -W no-dev ..
+cmake -W no-dev $OPTIONS ..
 make
 
 # As root:
